==> apache-druid-0.20.2-src.tar.gz: apache-druid-0.20.2-src/indexing-service/src/main/java/org/apache/druid/indexing/common/task/batch/parallel/PartialSegmentMergeIOConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.indexing.common.task.batch.parallel;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.Preconditions;
import org.apache.druid.segment.indexing.IOConfig;

import java.util.List;

abstract class PartialSegmentMergeIOConfig<T extends PartitionLocation> implements IOConfig
{
  private final List<T> partitionLocations;

  PartialSegmentMergeIOConfig(List<T> partitionLocations)
  {
    Preconditions.checkState(
        partitionLocations != null && !partitionLocations.isEmpty(),
        "Empty partition locations"
    );
    this.partitionLocations = partitionLocations;
  }

  @JsonProperty
  public List<T> getPartitionLocations()
  {
    return partitionLocations;
  }
}

==> apache-druid-36.0.0-src.tar.gz: apache-druid-36.0.0-src/indexing-service/src/main/java/org/apache/druid/indexing/common/task/batch/parallel/PartialSegmentMergeIOConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.indexing.common.task.batch.parallel;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.google.common.base.Preconditions;
import org.apache.druid.segment.indexing.IOConfig;

import java.util.List;

@JsonTypeName(PartialGenericSegmentMergeTask.TYPE)
public class PartialSegmentMergeIOConfig implements IOConfig
{
  private final List<PartitionLocation> partitionLocations;

  @JsonCreator
  PartialSegmentMergeIOConfig(@JsonProperty("partitionLocations") List<PartitionLocation> partitionLocations)
  {
    Preconditions.checkState(
        partitionLocations != null && !partitionLocations.isEmpty(),
        "Empty partition locations"
    );
    this.partitionLocations = partitionLocations;
  }

  @JsonProperty
  public List<PartitionLocation> getPartitionLocations()
  {
    return partitionLocations;
  }
}
